const PACKAGE_NAME = '@talend/react-components';

function matches(path) {
	return path.node.source.value.startsWith(PACKAGE_NAME);
}

module.exports = function transform({ types }) {
	return {
		visitor: {
			Program(path) {
				const imports = [];
				let lastImport;

				path.traverse({
					ImportDeclaration: {
						exit(importDeclarationPath) {
							if (matches(importDeclarationPath)) {
								imports.push(
									...importDeclarationPath.node.specifiers.map(({ local }) => local.name),
								);
								importDeclarationPath.remove();
							}
							lastImport = importDeclarationPath;
						},
					},
				});

				if (imports.length && lastImport) {
					const source = types.stringLiteral(PACKAGE_NAME);
					const specifiers = imports.map(name =>
						types.importSpecifier(types.identifier(name), types.identifier(name)),
					);
					const imp = types.importDeclaration(specifiers, source);
					lastImport.insertAfter(imp);
				}
			},
		},
	};
};
